@@ -36,10 +36,6 @@
 #endif
 #include <errno.h>
 #include <rfb/rfbclient.h>
-#ifdef WIN32
-#undef SOCKET
-#undef socklen_t
-#endif
 #ifdef LIBVNCSERVER_HAVE_LIBZ
 #include <zlib.h>
 #ifdef __CHECKER__
@@ -68,8 +64,6 @@
 #endif
 #include "tls.h"
 
-#include "VeyonRfbExt.h"
-
 #ifdef _MSC_VER
 #  define snprintf _snprintf /* MSVC went straight to the underscored syntax */
 #endif
@@ -218,13 +212,13 @@ SetServer2Client(rfbClient* client, int messageType)
 void
 ClearClient2Server(rfbClient* client, int messageType)
 {
-  client->supportedMessages.client2server[((messageType & 0xFF)/8)] &= (!(1<<(messageType % 8)));
+  client->supportedMessages.client2server[((messageType & 0xFF)/8)] &= ~(1<<(messageType % 8));
 }
 
 void
 ClearServer2Client(rfbClient* client, int messageType)
 {
-  client->supportedMessages.server2client[((messageType & 0xFF)/8)] &= (!(1<<(messageType % 8)));
+  client->supportedMessages.server2client[((messageType & 0xFF)/8)] &= ~(1<<(messageType % 8));
 }
 
 
@@ -322,7 +316,7 @@ ConnectToRFBServer(rfbClient* client,const char *hostname, int port)
       fclose(rec->file);
       return FALSE;
     }
-    client->sock = -1;
+    client->sock = INVALID_SOCKET;
     return TRUE;
   }
 
@@ -335,19 +329,24 @@ ConnectToRFBServer(rfbClient* client,const char *hostname, int port)
   {
 #ifdef LIBVNCSERVER_IPv6
     client->sock = ConnectClientToTcpAddr6(hostname, port);
+    if (client->sock == -1)
+    {
+    }
 #else
-	unsigned int host;
+    {
+      unsigned int host;
 
-	/* serverHost is a hostname */
-	if (!StringToIPAddr(hostname, &host)) {
-	  rfbClientLog("Couldn't convert '%s' to host address\n", hostname);
-	  return FALSE;
-	}
-	client->sock = ConnectClientToTcpAddr(host, port);
+      /* serverHost is a hostname */
+      if (!StringToIPAddr(hostname, &host)) {
+        rfbClientLog("Couldn't convert '%s' to host address\n", hostname);
+        return FALSE;
+      }
+      client->sock = ConnectClientToTcpAddr(host, port);
+    }
 #endif
   }
 
-  if (client->sock < 0) {
+  if (client->sock == INVALID_SOCKET) {
     rfbClientLog("Unable to connect to VNC server\n");
     return FALSE;
   }
@@ -371,17 +370,22 @@ rfbBool ConnectToRFBRepeater(rfbClient* client,const char *repeaterHost, int rep
 
 #ifdef LIBVNCSERVER_IPv6
   client->sock = ConnectClientToTcpAddr6(repeaterHost, repeaterPort);
-#else
-  unsigned int host;
-  if (!StringToIPAddr(repeaterHost, &host)) {
-	rfbClientLog("Couldn't convert '%s' to host address\n", repeaterHost);
-	return FALSE;
+  if (client->sock == -1)
+  {
   }
+#else
+  {
+    unsigned int host;
+    if (!StringToIPAddr(repeaterHost, &host)) {
+      rfbClientLog("Couldn't convert '%s' to host address\n", repeaterHost);
+      return FALSE;
+    }
 
-  client->sock = ConnectClientToTcpAddr(host, repeaterPort);
+    client->sock = ConnectClientToTcpAddr(host, repeaterPort);
+  }
 #endif
 
-  if (client->sock < 0) {
+  if (client->sock == INVALID_SOCKET) {
     rfbClientLog("Unable to connect to VNC repeater\n");
     return FALSE;
   }
@@ -507,7 +511,6 @@ ReadSupportedSecurityType(rfbClient* client, uint32_t *result, rfbBool subAuth)
             }
         }
         if (tAuth[loop]==rfbVncAuth || tAuth[loop]==rfbNoAuth ||
-			tAuth[loop] == rfbSecTypeVeyon ||
 			extAuthHandler ||
 #if defined(LIBVNCSERVER_HAVE_GNUTLS) || defined(LIBVNCSERVER_HAVE_LIBSSL)
             tAuth[loop]==rfbVeNCrypt ||
@@ -718,9 +721,9 @@ HandleMSLogonAuth(rfbClient *client)
   }
 
   memset(username, 0, sizeof(username));
-  strncpy((char *)username, cred->userCredential.username, sizeof(username));
+  strncpy((char *)username, cred->userCredential.username, sizeof(username)-1);
   memset(password, 0, sizeof(password));
-  strncpy((char *)password, cred->userCredential.password, sizeof(password));
+  strncpy((char *)password, cred->userCredential.password, sizeof(password)-1);
   FreeUserCredential(cred);
 
   srand(time(NULL));
@@ -1188,11 +1191,6 @@ InitialiseRFBConnection(rfbClient* client)
 
     break;
 
-  case rfbSecTypeVeyon:
-    handleSecTypeVeyon( client );
-    if (!rfbHandleAuthResult(client)) return FALSE;
-    break;
-
   default:
     {
       rfbBool authHandled=FALSE;
