@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef ACCESS_CONTROL_RULES_TEST_DIALOG_H
-#define ACCESS_CONTROL_RULES_TEST_DIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -45,5 +44,3 @@ public:
 private:
 	Ui::AccessControlRulesTestDialog *ui;
 };
-
-#endif // ACCESS_CONTROL_RULES_TEST_DIALOG_H
