@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2010-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef MAIN_WINDOW_H
-#define MAIN_WINDOW_H
+#pragma once
 
 #include <QMainWindow>
 
@@ -37,12 +36,13 @@ class MainWindow : public QMainWindow
 {
 	Q_OBJECT
 public:
-	MainWindow( QWidget* parent = nullptr );
+	explicit MainWindow( QWidget* parent = nullptr );
 	~MainWindow() override;
 
 	void reset( bool onlyUI = false );
 	void apply();
 
+	void updateView();
 
 private slots:
 	void configurationChanged();
@@ -54,6 +54,9 @@ private slots:
 
 
 private:
+	void switchToStandardView();
+	void switchToAdvancedView();
+
 	bool applyConfiguration();
 	void loadConfigurationPagePlugins();
 
@@ -63,5 +66,3 @@ private:
 	bool m_configChanged;
 
 } ;
-
-#endif
