@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef CONFIGURATION_PAGE_PLUGIN_INTERFACE_H
-#define CONFIGURATION_PAGE_PLUGIN_INTERFACE_H
+#pragma once
 
 #include "PluginInterface.h"
 
@@ -38,10 +37,8 @@ public:
 
 };
 
-typedef QList<ConfigurationPagePluginInterface> ConfigurationPagePluginInterfaceList;
+using ConfigurationPagePluginInterfaceList = QList<ConfigurationPagePluginInterface>;
 
 #define ConfigurationPagePluginInterface_iid "io.veyon.Veyon.Plugins.ConfigurationPagePluginInterface"
 
 Q_DECLARE_INTERFACE(ConfigurationPagePluginInterface, ConfigurationPagePluginInterface_iid)
-
-#endif // CONFIGURATION_PAGE_PLUGIN_INTERFACE_H
