@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef KEYBOARD_SHORTCUT_TRAPPER_H
-#define KEYBOARD_SHORTCUT_TRAPPER_H
+#pragma once
 
 #include "VeyonCore.h"
 
@@ -44,7 +43,7 @@ public:
 	} ;
 	Q_ENUM(Shortcut)
 
-	KeyboardShortcutTrapper( QObject* parent = nullptr ) :
+	explicit KeyboardShortcutTrapper( QObject* parent = nullptr ) :
 		QObject( parent )
 	{
 	}
@@ -55,5 +54,3 @@ signals:
 	void shortcutTrapped( Shortcut );
 
 } ;
-
-#endif
