@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
  *
- *  This file is part of Veyon - http://veyon.io
+ *  This file is part of Veyon - https://veyon.io
  *
  *  This is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,8 +21,7 @@
  *  USA.
  */
 
-#ifndef LOCK_WIDGET_H
-#define LOCK_WIDGET_H
+#pragma once
 
 #include <QWidget>
 #include <QPixmap>
@@ -34,14 +33,14 @@ class VEYON_CORE_EXPORT LockWidget : public QWidget
 {
 	Q_OBJECT
 public:
-	typedef enum Modes
+	enum Mode
 	{
 		DesktopVisible,
 		BackgroundPixmap,
 		NoBackground
-	} Mode;
+	} ;
 
-	LockWidget( Mode mode, const QPixmap& background = QPixmap(), QWidget* parent = nullptr );
+	explicit LockWidget( Mode mode, const QPixmap& background = QPixmap(), QWidget* parent = nullptr );
 	~LockWidget() override;
 
 
@@ -52,5 +51,3 @@ private:
 	Mode m_mode;
 
 } ;
-
-#endif
