@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef MONITORING_MODE_H
-#define MONITORING_MODE_H
+#pragma once
 
 #include "SimpleFeatureProvider.h"
 
@@ -32,7 +31,7 @@ class MonitoringMode : public QObject, SimpleFeatureProvider, PluginInterface
 	Q_OBJECT
 	Q_INTERFACES(FeatureProviderInterface PluginInterface)
 public:
-	MonitoringMode( QObject* parent = nullptr );
+	explicit MonitoringMode( QObject* parent = nullptr );
 
 	const Feature& feature() const
 	{
@@ -79,5 +78,3 @@ private:
 	const FeatureList m_features;
 
 };
-
-#endif // MONITORING_MODE_H
