@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2010-2016 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef PASSWORD_DIALOG_H
-#define PASSWORD_DIALOG_H
+#pragma once
 
 #include "AuthenticationCredentials.h"
 
@@ -35,7 +34,7 @@ class VEYON_CORE_EXPORT PasswordDialog : public QDialog
 {
 	Q_OBJECT
 public:
-	PasswordDialog( QWidget *parent );
+	explicit PasswordDialog( QWidget *parent );
 	~PasswordDialog() override;
 
 	QString username() const;
@@ -53,5 +52,3 @@ private:
 	Ui::PasswordDialog *ui;
 
 } ;
-
-#endif
