@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2010-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,26 +46,25 @@ AuthenticationCredentials::AuthenticationCredentials( const AuthenticationCreden
 
 
 
-bool AuthenticationCredentials::hasCredentials( TypeFlags credentialType ) const
+bool AuthenticationCredentials::hasCredentials( Type type ) const
 {
-	if( credentialType & PrivateKey )
+	switch( type )
 	{
+	case Type::PrivateKey:
 		return m_privateKey.isNull() == false;
-	}
 
-	if( credentialType & UserLogon )
-	{
-		return m_logonUsername.isEmpty() == false &&
-				m_logonPassword.isEmpty() == false;
-	}
+	case Type::UserLogon:
+		return m_logonUsername.isEmpty() == false && m_logonPassword.isEmpty() == false;
 
-	if( credentialType & Token )
-	{
+	case Type::Token:
 		return m_token.isEmpty() == false &&
 				QByteArray::fromBase64( m_token.toUtf8() ).size() == CryptoCore::ChallengeSize;
+
+	default:
+		break;
 	}
 
-	qCritical( "AuthenticationCredentials::hasCredentials(): no valid credential type given: %d", credentialType );
+	vCritical() << "no valid credential type given:" << TypeFlags( type );
 
 	return false;
 }
@@ -74,7 +73,7 @@ bool AuthenticationCredentials::hasCredentials( TypeFlags credentialType ) const
 
 bool AuthenticationCredentials::loadPrivateKey( const QString& privateKeyFile )
 {
-	qDebug() << "AuthenticationCredentials: loading private key" << privateKeyFile;
+	vDebug() << privateKeyFile;
 
 	if( privateKeyFile.isEmpty() )
 	{
