@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -28,11 +28,11 @@ Computer::Computer( NetworkObject::Uid networkObjectUid,
 					const QString& name,
 					const QString& hostAddress,
 					const QString& macAddress,
-					const QString& room ) :
+					const QString& location ) :
 	m_networkObjectUid( networkObjectUid ),
 	m_name( name ),
 	m_hostAddress( hostAddress ),
 	m_macAddress( macAddress ),
-	m_room( room )
+	m_location( location )
 {
 }
