@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -37,18 +37,22 @@ ComputerControlInterface::ComputerControlInterface( const Computer& computer,
 													QObject* parent ) :
 	QObject( parent ),
 	m_computer( computer ),
-	m_state( Disconnected ),
-	m_user(),
+	m_state( State::Disconnected ),
+	m_userLoginName(),
+	m_userFullName(),
 	m_scaledScreenSize(),
 	m_vncConnection( nullptr ),
 	m_connection( nullptr ),
-	m_builtinFeatures( nullptr ),
 	m_connectionWatchdogTimer( this ),
-	m_screenUpdated( false )
+	m_userUpdateTimer( this ),
+	m_activeFeaturesUpdateTimer( this )
 {
 	m_connectionWatchdogTimer.setInterval( ConnectionWatchdogTimeout );
 	m_connectionWatchdogTimer.setSingleShot( true );
 	connect( &m_connectionWatchdogTimer, &QTimer::timeout, this, &ComputerControlInterface::restartConnection );
+
+	connect( &m_userUpdateTimer, &QTimer::timeout, this, &ComputerControlInterface::updateUser );
+	connect( &m_activeFeaturesUpdateTimer, &QTimer::timeout, this, &ComputerControlInterface::updateActiveFeatures );
 }
 
 
@@ -60,54 +64,40 @@ ComputerControlInterface::~ComputerControlInterface()
 
 
 
-ComputerControlInterface::Pointer ComputerControlInterface::weakPointer()
-{
-	return Pointer( this, []( ComputerControlInterface* ) { } );
-}
-
-
-
-void ComputerControlInterface::start( QSize scaledScreenSize, BuiltinFeatures* builtinFeatures )
+void ComputerControlInterface::start( QSize scaledScreenSize )
 {
 	// make sure we do not leak
 	stop();
 
 	m_scaledScreenSize = scaledScreenSize;
-	m_builtinFeatures = builtinFeatures;
 
 	if( m_computer.hostAddress().isEmpty() == false )
 	{
 		m_vncConnection = new VncConnection();
 		m_vncConnection->setHost( m_computer.hostAddress() );
-		m_vncConnection->setQuality( VncConnection::ThumbnailQuality );
+		m_vncConnection->setQuality( VncConnection::Quality::Thumbnail );
 		m_vncConnection->setScaledSize( m_scaledScreenSize );
-		m_vncConnection->setFramebufferUpdateInterval( VeyonCore::config().computerMonitoringUpdateInterval() );
+
+		enableUpdates();
 
 		m_connection = new VeyonConnection( m_vncConnection );
 
 		m_vncConnection->start();
 
-		connect( m_vncConnection, &VncConnection::framebufferUpdateComplete, this, &ComputerControlInterface::setScreenUpdateFlag );
 		connect( m_vncConnection, &VncConnection::framebufferUpdateComplete, this, &ComputerControlInterface::resetWatchdog );
+		connect( m_vncConnection, &VncConnection::framebufferUpdateComplete, this, &ComputerControlInterface::screenUpdated );
 
 		connect( m_vncConnection, &VncConnection::stateChanged, this, &ComputerControlInterface::updateState );
 		connect( m_vncConnection, &VncConnection::stateChanged, this, &ComputerControlInterface::updateUser );
 		connect( m_vncConnection, &VncConnection::stateChanged, this, &ComputerControlInterface::updateActiveFeatures );
+		connect( m_vncConnection, &VncConnection::stateChanged, this, &ComputerControlInterface::stateChanged );
 
 		connect( m_connection, &VeyonConnection::featureMessageReceived, this, &ComputerControlInterface::handleFeatureMessage );
 		connect( m_connection, &VeyonConnection::featureMessageReceived, this, &ComputerControlInterface::resetWatchdog );
-
-		auto userUpdateTimer = new QTimer( m_connection );
-		connect( userUpdateTimer, &QTimer::timeout, this, &ComputerControlInterface::updateUser );
-		userUpdateTimer->start( UserUpdateInterval );
-
-		auto activeFeaturesUpdateTimer = new QTimer( m_connection );
-		connect( activeFeaturesUpdateTimer, &QTimer::timeout, this, &ComputerControlInterface::updateActiveFeatures );
-		activeFeaturesUpdateTimer->start( ActiveFeaturesUpdateInterval );
 	}
 	else
 	{
-		qWarning( "ComputerControlInterface::start(): computer host address is empty!" );
+		vWarning() << "computer host address is empty!";
 	}
 }
 
@@ -128,9 +118,11 @@ void ComputerControlInterface::stop()
 		m_vncConnection = nullptr;
 	}
 
+	m_activeFeaturesUpdateTimer.stop();
+	m_userUpdateTimer.stop();
 	m_connectionWatchdogTimer.stop();
 
-	m_state = Disconnected;
+	m_state = State::Disconnected;
 }
 
 
@@ -144,7 +136,7 @@ void ComputerControlInterface::setScaledScreenSize( QSize scaledScreenSize )
 		m_vncConnection->setScaledSize( m_scaledScreenSize );
 	}
 
-	setScreenUpdateFlag();
+	emit screenUpdated();
 }
 
 
@@ -173,11 +165,23 @@ QImage ComputerControlInterface::screen() const
 
 
 
-void ComputerControlInterface::setUser( const QString& user )
+void ComputerControlInterface::setUserLoginName( const QString& userLoginName )
 {
-	if( user != m_user )
+	if( userLoginName != m_userLoginName )
 	{
-		m_user = user;
+		m_userLoginName = userLoginName;
+
+		emit userChanged();
+	}
+}
+
+
+
+void ComputerControlInterface::setUserFullName( const QString& userFullName )
+{
+	if( userFullName != m_userFullName )
+	{
+		m_userFullName = userFullName;
 
 		emit userChanged();
 	}
@@ -206,19 +210,66 @@ void ComputerControlInterface::setDesignatedModeFeature( Feature::Uid designated
 
 
 
-void ComputerControlInterface::sendFeatureMessage( const FeatureMessage& featureMessage )
+void ComputerControlInterface::sendFeatureMessage( const FeatureMessage& featureMessage, bool wake )
 {
 	if( m_connection && m_connection->isConnected() )
 	{
-		m_connection->sendFeatureMessage( featureMessage );
+		m_connection->sendFeatureMessage( featureMessage, wake );
 	}
 }
 
 
 
+bool ComputerControlInterface::isMessageQueueEmpty()
+{
+	if( m_vncConnection && m_vncConnection->isConnected() )
+	{
+		return m_vncConnection->isEventQueueEmpty();
+	}
+
+	return true;
+}
+
+
+
+void ComputerControlInterface::enableUpdates()
+{
+	const auto updateInterval = VeyonCore::config().computerMonitoringUpdateInterval();
+
+	if( m_vncConnection )
+	{
+		m_vncConnection->setFramebufferUpdateInterval( updateInterval );
+	}
+
+	m_userUpdateTimer.start( updateInterval );
+	m_activeFeaturesUpdateTimer.start( updateInterval );
+}
+
+
+
+void ComputerControlInterface::disableUpdates()
+{
+	if( m_vncConnection )
+	{
+		m_vncConnection->setFramebufferUpdateInterval( UpdateIntervalWhenDisabled );
+	}
+
+	m_userUpdateTimer.stop();
+	m_activeFeaturesUpdateTimer.start( UpdateIntervalWhenDisabled );
+}
+
+
+
+ComputerControlInterface::Pointer ComputerControlInterface::weakPointer()
+{
+	return Pointer( this, []( ComputerControlInterface* ) { } );
+}
+
+
+
 void ComputerControlInterface::resetWatchdog()
 {
-	if( state() == Connected )
+	if( state() == State::Connected )
 	{
 		m_connectionWatchdogTimer.start();
 	}
@@ -230,7 +281,7 @@ void ComputerControlInterface::restartConnection()
 {
 	if( m_vncConnection )
 	{
-		qDebug() << Q_FUNC_INFO;
+		vDebug();
 		m_vncConnection->restart();
 
 		m_connectionWatchdogTimer.stop();
@@ -245,37 +296,36 @@ void ComputerControlInterface::updateState()
 	{
 		switch( m_vncConnection->state() )
 		{
-		case VncConnection::Disconnected: m_state = Disconnected; break;
-		case VncConnection::Connecting: m_state = Connecting; break;
-		case VncConnection::Connected: m_state = Connected; break;
-		case VncConnection::HostOffline: m_state = Offline; break;
-		case VncConnection::ServiceUnreachable: m_state = ServiceUnreachable; break;
-		case VncConnection::AuthenticationFailed: m_state = AuthenticationFailed; break;
-		default: m_state = Unknown; break;
+		case VncConnection::State::Disconnected: m_state = State::Disconnected; break;
+		case VncConnection::State::Connecting: m_state = State::Connecting; break;
+		case VncConnection::State::Connected: m_state = State::Connected; break;
+		case VncConnection::State::HostOffline: m_state = State::HostOffline; break;
+		case VncConnection::State::ServiceUnreachable: m_state = State::ServiceUnreachable; break;
+		case VncConnection::State::AuthenticationFailed: m_state = State::AuthenticationFailed; break;
+		default: m_state = VncConnection::State::Disconnected; break;
 		}
 	}
 	else
 	{
-		m_state = Disconnected;
+		m_state = State::Disconnected;
 	}
-
-	setScreenUpdateFlag();
 }
 
 
 
 void ComputerControlInterface::updateUser()
 {
-	if( m_vncConnection && m_connection && state() == Connected )
+	if( m_vncConnection && m_connection && state() == State::Connected )
 	{
-		if( user().isEmpty() )
+		if( userLoginName().isEmpty() )
 		{
-			m_builtinFeatures->userSessionControl().getUserSessionInfo( { weakPointer() } );
+			VeyonCore::builtinFeatures().userSessionControl().getUserSessionInfo( { weakPointer() } );
 		}
 	}
 	else
 	{
-		setUser( QString() );
+		setUserLoginName( {} );
+		setUserFullName( {} );
 	}
 }
 
@@ -283,9 +333,9 @@ void ComputerControlInterface::updateUser()
 
 void ComputerControlInterface::updateActiveFeatures()
 {
-	if( m_vncConnection && m_connection && state() == Connected )
+	if( m_vncConnection && m_connection && state() == State::Connected )
 	{
-		m_builtinFeatures->featureControl().queryActiveFeatures( { weakPointer() } );
+		VeyonCore::builtinFeatures().featureControl().queryActiveFeatures( { weakPointer() } );
 	}
 	else
 	{
