@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -26,12 +26,13 @@
 
 MonitoringMode::MonitoringMode( QObject* parent ) :
 	QObject( parent ),
-	m_monitoringModeFeature( Feature::Mode | Feature::Master | Feature::Builtin,
+	m_monitoringModeFeature( QLatin1String( staticMetaObject.className() ),
+							 Feature::Mode | Feature::Master | Feature::Builtin,
 							 Feature::Uid( "edad8259-b4ef-4ca5-90e6-f238d0fda694" ),
 							 Feature::Uid(),
 							 tr( "Monitoring" ), tr( "Monitoring" ),
-							 tr( "This is the default mode and allows you to monitor all computers in one or more rooms." ),
-							 QStringLiteral( ":/resources/presentation-none.png" ) ),
+							 tr( "This mode allows you to monitor all computers at one or more locations." ),
+							 QStringLiteral( ":/core/presentation-none.png" ) ),
 	m_features( { m_monitoringModeFeature } )
 {
 }
