@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,18 +22,16 @@
  *
  */
 
-#include "VeyonCore.h"
-
-#include <QBuffer>
-#include <QRegion>
-#include <QTcpSocket>
-
 extern "C"
 {
 #include "rfb/rfbproto.h"
 #include "common/d3des.h"
 }
 
+#include <QBuffer>
+#include <QRegion>
+#include <QTcpSocket>
+
 #include "VncClientProtocol.h"
 
 
@@ -140,11 +138,10 @@ bool VncClientProtocol::setEncodings( const QVector<uint32_t>& encodings )
 		return false;
 	}
 
-	char buf[sz_rfbSetEncodingsMsg + MAX_ENCODINGS * 4]; // Flawfinder: ignore
+	alignas(rfbSetEncodingsMsg) char buf[sz_rfbSetEncodingsMsg + MAX_ENCODINGS * 4]; // Flawfinder: ignore
 
 	auto setEncodingsMsg = reinterpret_cast<rfbSetEncodingsMsg *>( buf );
 	auto encs = reinterpret_cast<uint32_t *>( &buf[sz_rfbSetEncodingsMsg] );
-	int len = 0;
 
 	setEncodingsMsg->type = rfbSetEncodings;
 	setEncodingsMsg->pad = 0;
@@ -155,7 +152,7 @@ bool VncClientProtocol::setEncodings( const QVector<uint32_t>& encodings )
 		encs[setEncodingsMsg->nEncodings++] = qFromBigEndian<uint32_t>( encoding );
 	}
 
-	len = sz_rfbSetEncodingsMsg + setEncodingsMsg->nEncodings * 4;
+	const auto len = sz_rfbSetEncodingsMsg + setEncodingsMsg->nEncodings * 4;
 
 	setEncodingsMsg->nEncodings = qFromBigEndian(setEncodingsMsg->nEncodings);
 
@@ -177,7 +174,7 @@ void VncClientProtocol::requestFramebufferUpdate( bool incremental )
 
 	if( m_socket->write( reinterpret_cast<const char *>( &updateRequest ), sz_rfbFramebufferUpdateRequestMsg ) != sz_rfbFramebufferUpdateRequestMsg )
 	{
-		qDebug( "VncClientProtocol::requestFramebufferUpdate(): could not write to socket - closing connection" );
+		vDebug() << "could not write to socket - closing connection";
 		m_socket->close();
 	}
 }
@@ -213,10 +210,8 @@ bool VncClientProtocol::receiveMessage()
 		return receiveXvpMessage();
 
 	default:
-		qCritical( "VncClientProtocol::receiveMessage(): received unknown message type: %d",
-				   static_cast<int>( messageType ) );
+		vCritical() << "received unknown message type" << static_cast<int>( messageType );
 		m_socket->close();
-		return false;
 	}
 
 	return false;
@@ -232,7 +227,7 @@ bool VncClientProtocol::readProtocol()
 
 		if( protocol.size() != sz_rfbProtocolVersionMsg )
 		{
-			qCritical( "VncClientProtocol:::readProtocol(): protocol initialization failed" );
+			vCritical() << "protocol initialization failed";
 			m_socket->close();
 
 			return false;
@@ -244,13 +239,13 @@ bool VncClientProtocol::readProtocol()
 			protocolRX.cap( 1 ).toInt() != 3 ||
 			protocolRX.cap( 2 ).toInt() < 7 )
 		{
-			qCritical( "VncClientProtocol:::readProtocol(): invalid protocol version" );
+			vCritical() << "invalid protocol version";
 			m_socket->close();
 
 			return false;
 		}
 
-		m_socket->write( protocol, sz_rfbProtocolVersionMsg );
+		m_socket->write( protocol );
 
 		m_state = SecurityInit;
 
@@ -272,26 +267,26 @@ bool VncClientProtocol::receiveSecurityTypes()
 
 		if( securityTypeCount == 0 )
 		{
-			qCritical( "VncClientProtocol::receiveSecurityTypes(): invalid number of security types received!" );
+			vCritical() << "invalid number of security types received!";
 			m_socket->close();
 
 			return false;
 		}
 
-		auto securityTypeList = m_socket->read( securityTypeCount );
+		const auto securityTypeList = m_socket->read( securityTypeCount );
 		if( securityTypeList.count() != securityTypeCount )
 		{
-			qCritical( "VncClientProtocol::receiveSecurityTypes(): could not read security types!" );
+			vCritical() << "could not read security types!";
 			m_socket->close();
 
 			return false;
 		}
 
-		char securityType = rfbSecTypeVncAuth;
+		const char securityType = rfbSecTypeVncAuth;
 
 		if( securityTypeList.contains( securityType ) == false )
 		{
-			qCritical( "VncClientProtocol::receiveSecurityTypes(): no supported security type!" );
+			vCritical() << "no supported security type!";
 			m_socket->close();
 
 			return false;
@@ -340,12 +335,12 @@ bool VncClientProtocol::receiveSecurityResult()
 
 		if( qFromBigEndian( authResult ) != rfbVncAuthOK )
 		{
-			qCritical( "VncClientProtocol::receiveSecurityResult(): authentication failed!" );
+			vCritical() << "authentication failed!";
 			m_socket->close();
 			return false;
 		}
 
-		qDebug( "VncClientProtocol::receiveSecurityResult(): authentication successful" );
+		vDebug() << "authentication successful";
 
 		// finally send client init message
 		rfbClientInitMsg clientInitMessage;
@@ -370,11 +365,11 @@ bool VncClientProtocol::receiveServerInitMessage()
 	if( m_socket->bytesAvailable() >= sz_rfbServerInitMsg &&
 			m_socket->peek( reinterpret_cast<char *>( &message ), sz_rfbServerInitMsg ) == sz_rfbServerInitMsg )
 	{
-		auto nameLength = qFromBigEndian( message.nameLength );
+		const auto nameLength = qFromBigEndian( message.nameLength );
 
 		if( nameLength > 255 )
 		{
-			qCritical() << Q_FUNC_INFO << "size of desktop name > 255!";
+			vCritical() << "size of desktop name > 255!";
 			m_socket->close();
 			return false;
 		}
@@ -406,7 +401,7 @@ bool VncClientProtocol::receiveServerInitMessage()
 bool VncClientProtocol::receiveFramebufferUpdateMessage()
 {
 	// peek all available data and work on a local buffer so we can continously read from it
-	QByteArray data = m_socket->peek( m_socket->bytesAvailable() );
+	auto data = m_socket->peek( m_socket->bytesAvailable() );
 
 	QBuffer buffer( &data );
 	buffer.open( QBuffer::ReadOnly ); // Flawfinder: ignore
@@ -419,7 +414,7 @@ bool VncClientProtocol::receiveFramebufferUpdateMessage()
 
 	QRegion updatedRegion;
 
-	int nRects = qFromBigEndian( message.nRects );
+	const auto nRects = qFromBigEndian( message.nRects );
 
 	for( int i = 0; i < nRects; ++i )
 	{
@@ -456,7 +451,7 @@ bool VncClientProtocol::receiveFramebufferUpdateMessage()
 	m_lastUpdatedRect = updatedRegion.boundingRect();
 
 	// save as much data as we read by processing rects
-	return readMessage( buffer.pos() );
+	return readMessage( static_cast<int>( buffer.pos() ) );
 }
 
 
@@ -518,7 +513,7 @@ bool VncClientProtocol::receiveXvpMessage()
 
 
 
-bool VncClientProtocol::readMessage( qint64 size )
+bool VncClientProtocol::readMessage( int size )
 {
 	if( m_socket->bytesAvailable() < size )
 	{
@@ -532,7 +527,7 @@ bool VncClientProtocol::readMessage( qint64 size )
 		return true;
 	}
 
-	qWarning() << "VncClientProtocol::readMessage(): only received" << message.size() << "of" << size << "bytes";
+	vWarning() << "only received" << message.size() << "of" << size << "bytes";
 
 	return false;
 }
@@ -555,12 +550,12 @@ bool VncClientProtocol::handleRect( QBuffer& buffer, rfbFramebufferUpdateRectHea
 	case rfbEncodingXCursor:
 		return width * height == 0 ||
 				( buffer.read( sz_rfbXCursorColors ).size() == sz_rfbXCursorColors &&
-				  buffer.read( 2 * bytesPerRow * height ).size() == static_cast<qint64>( 2 * bytesPerRow * height ) );
+				  buffer.read( 2 * bytesPerRow * height ).size() == static_cast<int>( 2 * bytesPerRow * height ) );
 
 	case rfbEncodingRichCursor:
 		return width * height == 0 ||
-				( buffer.read( width * height * bytesPerPixel ).size() == static_cast<qint64>( width * height * bytesPerPixel ) &&
-				  buffer.read( bytesPerRow * height ).size() == static_cast<qint64>( bytesPerRow * height ) );
+				( buffer.read( width * height * bytesPerPixel ).size() == static_cast<int>( width * height * bytesPerPixel ) &&
+				  buffer.read( bytesPerRow * height ).size() == static_cast<int>( bytesPerRow * height ) );
 
 	case rfbEncodingSupportedMessages:
 		return buffer.read( sz_rfbSupportedMessages ).size() == sz_rfbSupportedMessages;
@@ -568,10 +563,10 @@ bool VncClientProtocol::handleRect( QBuffer& buffer, rfbFramebufferUpdateRectHea
 	case rfbEncodingSupportedEncodings:
 	case rfbEncodingServerIdentity:
 		// width = byte count
-		return buffer.read( width ).size() == static_cast<qint64>( width );
+		return buffer.read( width ).size() == static_cast<int>( width );
 
 	case rfbEncodingRaw:
-		return buffer.read( width * height * bytesPerPixel ).size() == static_cast<qint64>( width * height * bytesPerPixel );
+		return buffer.read( width * height * bytesPerPixel ).size() == static_cast<int>( width * height * bytesPerPixel );
 
 	case rfbEncodingCopyRect:
 		return buffer.read( sz_rfbCopyRect ).size() == sz_rfbCopyRect;
@@ -601,7 +596,7 @@ bool VncClientProtocol::handleRect( QBuffer& buffer, rfbFramebufferUpdateRectHea
 		return true;
 
 	default:
-		qCritical() << Q_FUNC_INFO << "Unsupported rect encoding" << rectHeader.encoding;
+		vCritical() << "Unsupported rect encoding" << rectHeader.encoding;
 		m_socket->close();
 		break;
 	}
@@ -621,7 +616,7 @@ bool VncClientProtocol::handleRectEncodingRRE( QBuffer& buffer, uint bytesPerPix
 	}
 
 	const auto rectDataSize = qFromBigEndian( hdr.nSubrects ) * ( bytesPerPixel + sz_rfbRectangle );
-	const auto totalDataSize = static_cast<qint64>( bytesPerPixel + rectDataSize );
+	const auto totalDataSize = static_cast<int>( bytesPerPixel + rectDataSize );
 
 	return buffer.read( totalDataSize ).size() == totalDataSize;
 }
@@ -638,7 +633,7 @@ bool VncClientProtocol::handleRectEncodingCoRRE( QBuffer& buffer, uint bytesPerP
 	}
 
 	const auto rectDataSize = qFromBigEndian( hdr.nSubrects ) * ( bytesPerPixel + 4 );
-	const auto totalDataSize = static_cast<qint64>( bytesPerPixel + rectDataSize );
+	const auto totalDataSize = static_cast<int>( bytesPerPixel + rectDataSize );
 
 	return buffer.read( totalDataSize ).size() == totalDataSize;
 
@@ -660,8 +655,14 @@ bool VncClientProtocol::handleRectEncodingHextile( QBuffer& buffer,
 		for( uint x = rx; x < rx+rw; x += 16 )
 		{
 			uint w = 16, h = 16;
-			if( rx+rw - x < 16 ) w = rx+rw - x;
-			if( ry+rh - y < 16 ) h = ry+rh - y;
+			if( rx+rw - x < 16 )
+			{
+				w = rx+rw - x;
+			}
+			if( ry+rh - y < 16 )
+			{
+				h = ry+rh - y;
+			}
 
 			uint8_t subEncoding = 0;
 			if( buffer.read( reinterpret_cast<char *>( &subEncoding ), 1 ) != 1 )
@@ -671,7 +672,7 @@ bool VncClientProtocol::handleRectEncodingHextile( QBuffer& buffer,
 
 			if( subEncoding & rfbHextileRaw )
 			{
-				const auto dataSize = static_cast<qint64>( w * h * bytesPerPixel );
+				const auto dataSize = static_cast<int>( w * h * bytesPerPixel );
 				if( buffer.read( dataSize ).size() != dataSize )
 				{
 					return false;
@@ -681,7 +682,7 @@ bool VncClientProtocol::handleRectEncodingHextile( QBuffer& buffer,
 
 			if( subEncoding & rfbHextileBackgroundSpecified )
 			{
-				if( buffer.read( bytesPerPixel ).size() != static_cast<qint64>( bytesPerPixel ) )
+				if( buffer.read( bytesPerPixel ).size() != static_cast<int>( bytesPerPixel ) )
 				{
 					return false;
 				}
@@ -689,7 +690,7 @@ bool VncClientProtocol::handleRectEncodingHextile( QBuffer& buffer,
 
 			if( subEncoding & rfbHextileForegroundSpecified )
 			{
-				if( buffer.read( bytesPerPixel ).size() != static_cast<qint64>( bytesPerPixel ) )
+				if( buffer.read( bytesPerPixel ).size() != static_cast<int>( bytesPerPixel ) )
 				{
 					return false;
 				}
@@ -706,11 +707,11 @@ bool VncClientProtocol::handleRectEncodingHextile( QBuffer& buffer,
 				return false;
 			}
 
-			int64_t subRectDataSize = 0;
+			int subRectDataSize = 0;
 
 			if( subEncoding & rfbHextileSubrectsColoured )
 			{
-				subRectDataSize = nSubrects * ( 2 + bytesPerPixel );
+				subRectDataSize = static_cast<int>( nSubrects * ( 2 + bytesPerPixel ) );
 			}
 			else
 			{
@@ -740,7 +741,7 @@ bool VncClientProtocol::handleRectEncodingZlib( QBuffer& buffer )
 
 	const auto n = qFromBigEndian( hdr.nBytes );
 
-	return buffer.read( n ).size() == static_cast<int64_t>( n );
+	return buffer.read( n ).size() == static_cast<int>( n );
 }
 
 
@@ -756,7 +757,7 @@ bool VncClientProtocol::handleRectEncodingZRLE(QBuffer &buffer)
 
 	const auto n = qFromBigEndian( hdr.length );
 
-	return buffer.read( n ).size() == static_cast<int64_t>( n );
+	return buffer.read( n ).size() == static_cast<int>( n );
 }
 
 
