@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef NETWORK_OBJECT_FILTER_PROXY_MODEL_H
-#define NETWORK_OBJECT_FILTER_PROXY_MODEL_H
+#pragma once
 
 #include <QSortFilterProxyModel>
 
@@ -31,7 +30,7 @@ class NetworkObjectFilterProxyModel : public QSortFilterProxyModel
 {
 	Q_OBJECT
 public:
-	NetworkObjectFilterProxyModel( QObject* parent );
+	explicit NetworkObjectFilterProxyModel( QObject* parent );
 
 	void setGroupFilter( const QStringList& groupList );
 	void setComputerExcludeFilter( const QStringList& computerExcludeList );
@@ -49,5 +48,3 @@ private:
 	bool m_excludeEmptyGroups;
 
 };
-
-#endif // NETWORK_OBJECT_FILTER_PROXY_MODEL_H
