@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2004-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -25,11 +25,12 @@
 #include <QApplication>
 #include <QSplashScreen>
 
+#include "DocumentationFigureCreator.h"
 #include "VeyonMaster.h"
 #include "MainWindow.h"
 
 
-int main( int argc, char * * argv )
+int main( int argc, char** argv )
 {
 	VeyonCore::setupApplicationParameters();
 
@@ -38,7 +39,15 @@ int main( int argc, char * * argv )
 
 	VeyonCore core( &app, QStringLiteral("Master") );
 
-	QSplashScreen splashScreen( QPixmap( QStringLiteral(":/resources/splash.png") ) );
+#ifdef VEYON_DEBUG
+	if( qEnvironmentVariableIsSet( "VEYON_MASTER_CREATE_DOC_FIGURES") )
+	{
+		DocumentationFigureCreator().run();
+		return 0;
+	}
+#endif
+
+	QSplashScreen splashScreen( QPixmap( QStringLiteral(":/master/splash.png") ) );
 	splashScreen.show();
 
 	if( MainWindow::initAuthentication() == false ||
@@ -47,14 +56,12 @@ int main( int argc, char * * argv )
 		return -1;
 	}
 
-	VeyonMaster masterCore;
+	VeyonMaster masterCore( &core );
 
 	// hide splash-screen as soon as main-window is shown
 	splashScreen.finish( masterCore.mainWindow() );
 
 	masterCore.mainWindow()->show();
 
-	qInfo( "Master: running" );
-
-	return app.exec();
+	return core.exec();
 }
