@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -36,6 +36,8 @@ DemoServer::DemoServer( int vncServerPort, const QString& vncServerPassword, con
 						const DemoConfiguration& configuration, QObject *parent ) :
 	QObject( parent ),
 	m_configuration( configuration ),
+	m_memoryLimit( m_configuration.memoryLimit() * 1024*1024 ),
+	m_keyFrameInterval( m_configuration.keyFrameInterval() * 1000 ),
 	m_vncServerPort( vncServerPort ),
 	m_demoAccessToken( demoAccessToken ),
 	m_tcpServer( new QTcpServer( this ) ),
@@ -53,9 +55,9 @@ DemoServer::DemoServer( int vncServerPort, const QString& vncServerPassword, con
 
 	connect( &m_framebufferUpdateTimer, &QTimer::timeout, this, &DemoServer::requestFramebufferUpdate );
 
-	if( m_tcpServer->listen( QHostAddress::Any, VeyonCore::config().demoServerPort() ) == false )
+	if( m_tcpServer->listen( QHostAddress::Any, static_cast<quint16>( VeyonCore::config().demoServerPort() ) ) == false )
 	{
-		qCritical( "DemoServer: could not listen to demo server port!" );
+		vCritical() << "could not listen to demo server port";
 		return;
 	}
 
@@ -68,11 +70,11 @@ DemoServer::DemoServer( int vncServerPort, const QString& vncServerPassword, con
 
 DemoServer::~DemoServer()
 {
-	qDebug() << Q_FUNC_INFO << "disconnecting signals";
+	vDebug() << "disconnecting signals";
 	m_vncServerSocket->disconnect( this );
 	m_tcpServer->disconnect( this );
 
-	qDebug() << Q_FUNC_INFO << "deleting connections";
+	vDebug() << "deleting connections";
 
 	QList<DemoServerConnection *> l;
 	while( !( l = findChildren<DemoServerConnection *>() ).isEmpty() )
@@ -80,13 +82,29 @@ DemoServer::~DemoServer()
 		delete l.front();
 	}
 
-	qDebug() << Q_FUNC_INFO << "deleting server socket";
+	vDebug() << "deleting server socket";
 	delete m_vncServerSocket;
 
-	qDebug() << Q_FUNC_INFO << "deleting TCP server";
+	vDebug() << "deleting TCP server";
 	delete m_tcpServer;
 
-	qDebug() << Q_FUNC_INFO << "finished";
+	vDebug() << "finished";
+}
+
+
+
+void DemoServer::lockDataForRead()
+{
+	QElapsedTimer readLockTimer;
+	readLockTimer.restart();
+
+	m_dataLock.lockForRead();
+
+	if( readLockTimer.elapsed() > 100 )
+	{
+		vDebug() << "locking for read took" << readLockTimer.elapsed() << "ms in thread"
+				 << QThread::currentThreadId();
+	}
 }
 
 
@@ -110,7 +128,7 @@ void DemoServer::reconnectToVncServer()
 {
 	m_vncClientProtocol.start();
 
-	m_vncServerSocket->connectToHost( QHostAddress::LocalHost, m_vncServerPort );
+	m_vncServerSocket->connectToHost( QHostAddress::LocalHost, static_cast<quint16>( m_vncServerPort ) );
 }
 
 
@@ -146,8 +164,9 @@ void DemoServer::requestFramebufferUpdate()
 	}
 
 	if( m_requestFullFramebufferUpdate ||
-			m_lastFullFramebufferUpdate.elapsed() >= m_configuration.keyFrameInterval() * 1000 )
+		m_lastFullFramebufferUpdate.elapsed() >= m_keyFrameInterval )
 	{
+		vDebug() << "Requesting full framebuffer update";
 		m_vncClientProtocol.requestFramebufferUpdate( false );
 		m_lastFullFramebufferUpdate.restart();
 		m_requestFullFramebufferUpdate = false;
@@ -170,7 +189,7 @@ bool DemoServer::receiveVncServerMessage()
 		}
 		else
 		{
-			qWarning( "DemoServer: skipping server message of type %d", (int) m_vncClientProtocol.lastMessageType() );
+			vWarning() << "skipping server message of type" << static_cast<int>( m_vncClientProtocol.lastMessageType() );
 		}
 
 		return true;
@@ -183,29 +202,36 @@ bool DemoServer::receiveVncServerMessage()
 
 void DemoServer::enqueueFramebufferUpdateMessage( const QByteArray& message )
 {
-	bool isFullUpdate = false;
-	const auto lastUpdatedRect = m_vncClientProtocol.lastUpdatedRect();
-
-	if( lastUpdatedRect.x() == 0 && lastUpdatedRect.y() == 0 &&
-			lastUpdatedRect.width() == m_vncClientProtocol.framebufferWidth() &&
-			lastUpdatedRect.height() == m_vncClientProtocol.framebufferHeight() )
-	{
-		isFullUpdate = true;
-	}
+	QElapsedTimer writeLockTime;
+	writeLockTime.start();
 
 	m_dataLock.lockForWrite();
 
-	if( isFullUpdate || framebufferUpdateMessageQueueSize() > m_configuration.memoryLimit()*2*1024*1024  )
+	if( writeLockTime.elapsed() > 10 )
+	{
+		vDebug() << "locking for write took" << writeLockTime.elapsed() << "ms";
+	}
+
+	const auto lastUpdatedRect = m_vncClientProtocol.lastUpdatedRect();
+
+	const bool isFullUpdate = ( lastUpdatedRect.x() == 0 && lastUpdatedRect.y() == 0 &&
+								lastUpdatedRect.width() == m_vncClientProtocol.framebufferWidth() &&
+								lastUpdatedRect.height() == m_vncClientProtocol.framebufferHeight() );
+
+	const auto queueSize = framebufferUpdateMessageQueueSize();
+
+	if( isFullUpdate || queueSize > m_memoryLimit*2 )
 	{
 		if( m_keyFrameTimer.elapsed() > 1 )
 		{
-			const auto memTotal = framebufferUpdateMessageQueueSize() / 1024;
-			qDebug() << Q_FUNC_INFO
+			const auto memTotal = queueSize / 1024;
+			vDebug()
 					 << "   MEMTOTAL:" << memTotal
 					 << "   KB/s:" << ( memTotal * 1000 ) / m_keyFrameTimer.elapsed();
 		}
 		m_keyFrameTimer.restart();
 		++m_keyFrame;
+
 		m_framebufferUpdateMessages.clear();
 	}
 
@@ -214,7 +240,7 @@ void DemoServer::enqueueFramebufferUpdateMessage( const QByteArray& message )
 	m_dataLock.unlock();
 
 	// we're about to reach memory limits?
-	if( framebufferUpdateMessageQueueSize() > m_configuration.memoryLimit() * 1024 * 1024 )
+	if( framebufferUpdateMessageQueueSize() > m_memoryLimit )
 	{
 		// then request a full update so we can clear our queue
 		m_requestFullFramebufferUpdate = true;
