@@ -4,7 +4,7 @@
  *
  * Copyright (c) 2006-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -101,7 +101,7 @@ bool DemoServerConnection::receiveClientMessage()
 		if( m_socket->bytesAvailable() >= sz_rfbSetEncodingsMsg )
 		{
 			rfbSetEncodingsMsg setEncodingsMessage;
-			if( m_socket->peek( (char *) &setEncodingsMessage, sz_rfbSetEncodingsMsg ) == sz_rfbSetEncodingsMsg )
+			if( m_socket->peek( reinterpret_cast<char *>( &setEncodingsMessage ), sz_rfbSetEncodingsMsg ) == sz_rfbSetEncodingsMsg )
 			{
 				const qint64 totalSize = sz_rfbSetEncodingsMsg + qFromBigEndian(setEncodingsMessage.nEncodings) * sizeof(uint32_t);
 				if( m_socket->bytesAvailable() >= totalSize )
@@ -115,7 +115,7 @@ bool DemoServerConnection::receiveClientMessage()
 	default:
 		if( m_rfbClientToServerMessageSizes.contains( messageType ) == false )
 		{
-			qCritical( "DemoServerConnection::receiveMessageFromClient(): received unknown message type: %d", (int) messageType );
+			vCritical() << "received unknown message type:" << static_cast<int>( messageType );
 			m_socket->close();
 			return false;
 		}
