@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -50,7 +50,7 @@ void DemoServerProtocol::processAuthenticationMessage( VariantArrayMessage& mess
 	}
 	else
 	{
-		client()->setAuthState( VncServerClient::AuthFinishedFail );
+		client()->setAuthState( VncServerClient::AuthState::Failed );
 	}
 }
 
@@ -58,7 +58,7 @@ void DemoServerProtocol::processAuthenticationMessage( VariantArrayMessage& mess
 
 void DemoServerProtocol::performAccessControl()
 {
-	client()->setAccessControlState( VncServerClient::AccessControlSuccessful );
+	client()->setAccessControlState( VncServerClient::AccessControlState::Successful );
 }
 
 
@@ -67,22 +67,22 @@ VncServerClient::AuthState DemoServerProtocol::performTokenAuthentication( Varia
 {
 	switch( client()->authState() )
 	{
-	case VncServerClient::AuthInit:
-		return VncServerClient::AuthToken;
+	case VncServerClient::AuthState::Init:
+		return VncServerClient::AuthState::Token;
 
-	case VncServerClient::AuthToken:
+	case VncServerClient::AuthState::Token:
 		if( message.read().toString() == m_demoAccessToken )
 		{
-			qDebug( "DemoServerProtocol::performTokenAuthentication(): SUCCESS" );
-			return VncServerClient::AuthFinishedSuccess;
+			vDebug() << "SUCCESS";
+			return VncServerClient::AuthState::Successful;
 		}
 
-		qDebug( "DemoServerProtocol::performTokenAuthentication(): FAIL" );
-		return VncServerClient::AuthFinishedFail;
+		vDebug() << "FAIL";
+		return VncServerClient::AuthState::Failed;
 
 	default:
 		break;
 	}
 
-	return VncServerClient::AuthFinishedFail;
+	return VncServerClient::AuthState::Failed;
 }
