@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -51,6 +51,13 @@ LinuxCoreFunctions::LinuxCoreFunctions() :
 
 
 
+bool LinuxCoreFunctions::applyConfiguration()
+{
+	return true;
+}
+
+
+
 void LinuxCoreFunctions::initNativeLoggingSystem( const QString& appName )
 {
 	Q_UNUSED(appName)
@@ -88,8 +95,10 @@ void LinuxCoreFunctions::reboot()
 
 
 
-void LinuxCoreFunctions::powerDown()
+void LinuxCoreFunctions::powerDown( bool installUpdates )
 {
+	Q_UNUSED(installUpdates)
+
 	if( isRunningAsAdmin() )
 	{
 		QProcess::startDetached( QStringLiteral("poweroff") );
@@ -147,7 +156,7 @@ void LinuxCoreFunctions::disableScreenSaver()
 	}
 	else
 	{
-		qWarning() << Q_FUNC_INFO << "DPMS extension not supported!";
+		vWarning() << "DPMS extension not supported!";
 	}
 
 	XFlush( display );
@@ -183,6 +192,13 @@ void LinuxCoreFunctions::restoreScreenSaverSettings()
 
 
 
+void LinuxCoreFunctions::setSystemUiState( bool enabled )
+{
+	Q_UNUSED(enabled)
+}
+
+
+
 QString LinuxCoreFunctions::activeDesktopName()
 {
 	return QString();
@@ -202,7 +218,7 @@ bool LinuxCoreFunctions::runProgramAsAdmin( const QString& program, const QStrin
 	const auto commandLine = QStringList( program ) + parameters;
 
 	const auto desktop = QProcessEnvironment::systemEnvironment().value( QStringLiteral("XDG_CURRENT_DESKTOP") );
-	if( desktop == QStringLiteral("KDE") &&
+	if( desktop == QLatin1String("KDE") &&
 			QStandardPaths::findExecutable( QStringLiteral("kdesudo") ).isEmpty() == false )
 	{
 		return QProcess::execute( QStringLiteral("kdesudo"), commandLine ) == 0;
@@ -223,9 +239,11 @@ bool LinuxCoreFunctions::runProgramAsUser( const QString& program, const QString
 {
 	Q_UNUSED(desktop);
 
-	class UserProcess : public QProcess {
+	class UserProcess : public QProcess // clazy:exclude=missing-qobject-macro
+	{
 	public:
-		UserProcess( uid_t uid ) :
+		explicit UserProcess( uid_t uid, QObject* parent = nullptr ) :
+			QProcess( parent ),
 			m_uid( uid )
 		{
 		}
