@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -24,10 +24,8 @@
 
 #include <QDateTime>
 #include <QDBusReply>
-#include <QElapsedTimer>
 #include <QEventLoop>
 #include <QProcess>
-#include <QThread>
 #include <QTimer>
 
 #include <proc/readproc.h>
@@ -35,13 +33,12 @@
 #include "Filesystem.h"
 #include "LinuxCoreFunctions.h"
 #include "LinuxServiceCore.h"
-#include "VeyonConfiguration.h"
+#include "ProcessHelper.h"
 
 
 LinuxServiceCore::LinuxServiceCore( QObject* parent ) :
 	QObject( parent ),
-	m_loginManager( LinuxCoreFunctions::systemdLoginManager() ),
-	m_multiSession( VeyonCore::config().isMultiSessionServiceEnabled() )
+	m_loginManager( LinuxCoreFunctions::systemdLoginManager() )
 {
 	connectToLoginManager();
 }
@@ -70,47 +67,20 @@ void LinuxServiceCore::run()
 
 
 
-void LinuxServiceCore::connectToLoginManager()
-{
-	bool success = true;
-
-	const auto service = m_loginManager->service();
-	const auto path = m_loginManager->path();
-	const auto interface = m_loginManager->interface();
-
-	success &= QDBusConnection::systemBus().connect( service, path, interface, QStringLiteral("SessionNew"),
-													 this, SLOT(startServer(QString,QDBusObjectPath)) );
-
-	success &= QDBusConnection::systemBus().connect( service, path, interface, QStringLiteral("SessionRemoved"),
-													 this, SLOT(stopServer(QString,QDBusObjectPath)) );
-
-	if( success == false )
-	{
-		qWarning() << Q_FUNC_INFO << "could not connect to login manager! retrying in" << LoginManagerReconnectInterval << "msecs";
-		QTimer::singleShot( LoginManagerReconnectInterval, this, &LinuxServiceCore::connectToLoginManager );
-	}
-	else
-	{
-		qDebug( "LinuxServiceCore: connected to login manager" );
-	}
-}
-
-
-
 void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusObjectPath& sessionObjectPath )
 {
 	const auto sessionPath = sessionObjectPath.path();
 
 	const auto sessionType = getSessionType( sessionPath );
 
-	if( sessionType == QStringLiteral("wayland") )
+	if( sessionType == QLatin1String("wayland") )
 	{
-		qCritical() << "Can't start Veyon Server in Wayland sessions as this is not yet supported. Please switch to X11-based sessions!";
+		vCritical() << "Can't start Veyon Server in Wayland sessions as this is not yet supported. Please switch to X11-based sessions!";
 		return;
 	}
 
 	// do not start server for non-graphical sessions
-	if( sessionType != QStringLiteral("x11") )
+	if( sessionType != QLatin1String("x11") )
 	{
 		return;
 	}
@@ -118,7 +88,7 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 	const auto sessionLeader = getSessionLeaderPid( sessionPath );
 	if( sessionLeader < 0 )
 	{
-		qCritical() << "No leader available for session" << sessionPath;
+		vCritical() << "No leader available for session" << sessionPath;
 		return;
 	}
 
@@ -126,14 +96,14 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 
 	if( sessionEnvironment.isEmpty() )
 	{
-		qWarning() << "Environment for session" << sessionPath << "not yet available - retrying in"
+		vWarning() << "Environment for session" << sessionPath << "not yet available - retrying in"
 				   << SessionEnvironmentProbingInterval << "msecs";
 		QTimer::singleShot( SessionEnvironmentProbingInterval, this,
 							[=]() { startServer( login1SessionId, sessionObjectPath ); } );
 		return;
 	}
 
-	if( m_multiSession == false && m_serverProcesses.isEmpty() == false )
+	if( multiSession() == false && m_serverProcesses.isEmpty() == false )
 	{
 		// make sure no other server is still running
 		stopAllServers();
@@ -143,7 +113,7 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 
 	if( sessionUptime >= 0 && sessionUptime < SessionUptimeSecondsMinimum )
 	{
-		qDebug() << "Session" << sessionPath << "too young - retrying in" << SessionUptimeProbingInterval << "msecs";
+		vDebug() << "Session" << sessionPath << "too young - retrying in" << SessionUptimeProbingInterval << "msecs";
 		QTimer::singleShot( SessionUptimeProbingInterval, this, [=]() { startServer( login1SessionId, sessionObjectPath ); } );
 		return;
 	}
@@ -151,11 +121,11 @@ void LinuxServiceCore::startServer( const QString& login1SessionId, const QDBusO
 	const auto seat = getSessionSeat( sessionPath );
 	const auto display = getSessionDisplay( sessionPath );
 
-	qInfo() << "Starting server for new session" << sessionPath
+	vInfo() << "Starting server for new session" << sessionPath
 			<< "with display" << display
 			<< "at seat" << seat.path;
 
-	if( m_multiSession )
+	if( multiSession() )
 	{
 		const auto sessionId = openSession( QStringList( { sessionPath, display, seat.path } ) );
 		sessionEnvironment.insert( VeyonCore::sessionIdEnvironmentVariable(), QString::number( sessionId ) );
@@ -184,30 +154,53 @@ void LinuxServiceCore::stopServer( const QString& login1SessionId, const QDBusOb
 
 
 
+void LinuxServiceCore::connectToLoginManager()
+{
+	bool success = true;
+
+	const auto service = m_loginManager->service();
+	const auto path = m_loginManager->path();
+	const auto interface = m_loginManager->interface();
+
+	success &= QDBusConnection::systemBus().connect( service, path, interface, QStringLiteral("SessionNew"),
+													 this, SLOT(startServer(QString,QDBusObjectPath)) );
+
+	success &= QDBusConnection::systemBus().connect( service, path, interface, QStringLiteral("SessionRemoved"),
+													 this, SLOT(stopServer(QString,QDBusObjectPath)) );
+
+	if( success == false )
+	{
+		vWarning() << "could not connect to login manager! retrying in" << LoginManagerReconnectInterval << "msecs";
+		QTimer::singleShot( LoginManagerReconnectInterval, this, &LinuxServiceCore::connectToLoginManager );
+	}
+	else
+	{
+		vDebug() << "connected to login manager";
+	}
+}
+
+
+
 void LinuxServiceCore::stopServer( const QString& sessionPath )
 {
-	qInfo() << "Stopping server for removed session" << sessionPath;
-
-	auto process = m_serverProcesses[sessionPath];
-	process->terminate();
-
-	QElapsedTimer serverStopTimer;
-	serverStopTimer.start();
-
-	while( process->state() != QProcess::NotRunning )
+	if( m_serverProcesses.contains( sessionPath ) == false )
 	{
-		if( serverStopTimer.elapsed() >= ServerTerminateTimeout )
-		{
-			qWarning() << "Server for session" << sessionPath << "still running - killing now";
-			process->kill();
-			QThread::msleep( ServerKillDelayTime );
-			break;
-		}
-
-		QThread::msleep( ServerStopSleepInterval );
+		return;
 	}
 
-	if( m_multiSession )
+	vInfo() << "stopping server for removed session" << sessionPath;
+
+	auto process = qAsConst(m_serverProcesses)[sessionPath];
+	process->terminate();
+
+	if( ProcessHelper::waitForProcess( process, ServerTerminateTimeout, ServerWaitSleepInterval ) == false )
+	{
+		vWarning() << "server for session" << sessionPath << "still running - killing now";
+		process->kill();
+		ProcessHelper::waitForProcess( process, ServerKillTimeout, ServerWaitSleepInterval );
+	}
+
+	if( multiSession() )
 	{
 		closeSession( process->processEnvironment().value( VeyonCore::sessionIdEnvironmentVariable() ).toInt() );
 	}
@@ -253,7 +246,7 @@ QStringList LinuxServiceCore::listSessions()
 	}
 	else
 	{
-		qCritical() << Q_FUNC_INFO << "Could not query sessions:" << reply.error().message();
+		vCritical() << "Could not query sessions:" << reply.error().message();
 	}
 
 	return sessions;
@@ -274,7 +267,7 @@ QVariant LinuxServiceCore::getSessionProperty( const QString& session, const QSt
 
 	if( reply.isValid() == false )
 	{
-		qCritical() << "Could not query session property" << property << reply.error().message();
+		vCritical() << "Could not query session property" << property << reply.error().message();
 		return QVariant();
 	}
 
@@ -363,8 +356,8 @@ QProcessEnvironment LinuxServiceCore::getSessionEnvironment( int sessionLeaderPi
 		{
 			for( int i = 0; procInfo->environ[i]; ++i )
 			{
-				const auto env = QString( procInfo->environ[i] ).split( '=' );
-				sessionEnv.insert( env.first(), env.mid( 1 ).join( '=' ) );
+				const auto env = QString::fromUtf8( procInfo->environ[i] ).split( QLatin1Char('=') );
+				sessionEnv.insert( env.first(), env.mid( 1 ).join( QLatin1Char('=') ) );
 			}
 
 			ppids.append( procInfo->tid );
