@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -28,7 +28,7 @@
 
 QString LinuxServiceFunctions::veyonServiceName() const
 {
-	return QStringLiteral("veyon-service");
+	return QStringLiteral("veyon");
 }
 
 
@@ -37,7 +37,7 @@ bool LinuxServiceFunctions::isRegistered( const QString& name )
 {
 	Q_UNUSED(name);
 
-	qCritical( "Querying service registration is not supported on this platform.");
+	vCritical() << "Querying service registration is not supported on this platform.";
 
 	return false;
 }
@@ -73,7 +73,7 @@ bool LinuxServiceFunctions::install( const QString& name, const QString& filePat
 	Q_UNUSED(startMode)
 	Q_UNUSED(displayName)
 
-	qCritical( "Registering services is not supported on this platform.");
+	vCritical() << "Registering services is not supported on this platform.";
 
 	return false;
 }
@@ -84,7 +84,7 @@ bool LinuxServiceFunctions::uninstall( const QString& name )
 {
 	Q_UNUSED(name)
 
-	qCritical( "Unregistering services is not supported on this platform.");
+	vCritical() << "Unregistering services is not supported on this platform.";
 
 	return false;
 }
@@ -93,7 +93,7 @@ bool LinuxServiceFunctions::uninstall( const QString& name )
 
 bool LinuxServiceFunctions::setStartMode( const QString& name, PlatformServiceFunctions::StartMode startMode )
 {
-	if( startMode == StartModeAuto )
+	if( startMode == StartMode::Auto )
 	{
 		return systemctl( { QStringLiteral("enable"), name } ) == 0;
 	}
