@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef LINUX_USER_FUNCTIONS_H
-#define LINUX_USER_FUNCTIONS_H
+#pragma once
 
 #include "PlatformUserFunctions.h"
 
@@ -39,20 +38,18 @@ public:
 	QStringList userGroups( bool queryDomainGroups ) override;
 	QStringList groupsOfUser( const QString& username, bool queryDomainGroups ) override;
 
+	bool isAnyUserLoggedOn() override;
 	QString currentUser() override;
-	QStringList loggedOnUsers() override;
 
 	void logon( const QString& username, const QString& password ) override;
-	void logout() override;
+	void logoff() override;
 
 	bool authenticate( const QString& username, const QString& password ) override;
 
 	static uid_t userIdFromName( const QString& username );
 
 private:
-	enum {
-		WhoProcessTimeout = 3000
-	};
-};
+	static constexpr auto WhoProcessTimeout = 3000;
+	static constexpr auto AuthHelperTimeout = 10000;
 
-#endif // LINUX_USER_FUNCTIONS_H
+};
