@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,20 +22,25 @@
  *
  */
 
-#ifndef POWER_CONTROL_FEATURE_PLUGIN_H
-#define POWER_CONTROL_FEATURE_PLUGIN_H
+#pragma once
 
+#include "CommandLineIO.h"
+#include "CommandLinePluginInterface.h"
 #include "Feature.h"
-#include "FeatureProviderInterface.h"
+#include "SimpleFeatureProvider.h"
 
-class PowerControlFeaturePlugin : public QObject, FeatureProviderInterface, PluginInterface
+class PowerControlFeaturePlugin : public QObject,
+		PluginInterface,
+		CommandLineIO,
+		CommandLinePluginInterface,
+		SimpleFeatureProvider
 {
 	Q_OBJECT
 	Q_PLUGIN_METADATA(IID "io.veyon.Veyon.Plugins.PowerControl")
-	Q_INTERFACES(PluginInterface FeatureProviderInterface)
+	Q_INTERFACES(PluginInterface CommandLinePluginInterface FeatureProviderInterface)
 public:
-	PowerControlFeaturePlugin( QObject* parent = nullptr );
-	~PowerControlFeaturePlugin() override {}
+	explicit PowerControlFeaturePlugin( QObject* parent = nullptr );
+	~PowerControlFeaturePlugin() override = default;
 
 	Plugin::Uid uid() const override
 	{
@@ -44,7 +49,7 @@ public:
 
 	QVersionNumber version() const override
 	{
-		return QVersionNumber( 1, 1 );
+		return QVersionNumber( 1, 2 );
 	}
 
 	QString name() const override
@@ -67,30 +72,54 @@ public:
 		return QStringLiteral("Tobias Junghans");
 	}
 
+	QString commandLineModuleName() const override
+	{
+		return QStringLiteral( "power" );
+	}
+
+	QString commandLineModuleHelp() const override
+	{
+		return tr( "Commands for controlling power status of computers" );
+	}
+
+	QStringList commands() const override;
+	QString commandHelp( const QString& command ) const override;
+
 	const FeatureList& featureList() const override;
 
 	bool startFeature( VeyonMasterInterface& master, const Feature& feature,
 					   const ComputerControlInterfaceList& computerControlInterfaces ) override;
 
-	bool stopFeature( VeyonMasterInterface& master, const Feature& feature,
-					  const ComputerControlInterfaceList& computerControlInterfaces ) override;
-
-	bool handleFeatureMessage( VeyonMasterInterface& master, const FeatureMessage& message,
-							   ComputerControlInterface::Pointer computerControlInterface ) override;
-
-	bool handleFeatureMessage( VeyonServerInterface& server, const FeatureMessage& message ) override;
+	bool handleFeatureMessage( VeyonServerInterface& server,
+							   const MessageContext& messageContext,
+							   const FeatureMessage& message ) override;
 
 	bool handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message ) override;
 
+public slots:
+	CommandLinePluginInterface::RunResult handle_help( const QStringList& arguments );
+	CommandLinePluginInterface::RunResult handle_on( const QStringList& arguments );
+
 private:
+	enum Arguments {
+		ShutdownTimeout
+	};
+
 	bool confirmFeatureExecution( const Feature& feature, QWidget* parent );
-	static void broadcastWOLPacket( QString macAddress );
+	static bool broadcastWOLPacket( QString macAddress );
+
+	void confirmShutdown();
+	void displayShutdownTimeout( int shutdownTimeout );
+
+	QMap<QString, QString> m_commands;
 
 	const Feature m_powerOnFeature;
 	const Feature m_rebootFeature;
 	const Feature m_powerDownFeature;
+	const Feature m_powerDownNowFeature;
+	const Feature m_installUpdatesAndPowerDownFeature;
+	const Feature m_powerDownConfirmedFeature;
+	const Feature m_powerDownDelayedFeature;
 	const FeatureList m_features;
 
 };
-
-#endif // POWER_CONTROL_FEATURE_PLUGIN_H
