@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -33,16 +33,18 @@
 
 RemoteAccessFeaturePlugin::RemoteAccessFeaturePlugin( QObject* parent ) :
 	QObject( parent ),
-	m_remoteViewFeature( Feature::Session | Feature::Master,
+	m_remoteViewFeature( QStringLiteral( "RemoteView" ),
+						 Feature::Session | Feature::Master,
 						 Feature::Uid( "a18e545b-1321-4d4e-ac34-adc421c6e9c8" ),
 						 Feature::Uid(),
-						 tr( "Remote view" ), QString(),
+						 tr( "Remote view" ), {},
 						 tr( "Open a remote view for a computer without interaction." ),
 						 QStringLiteral(":/remoteaccess/kmag.png") ),
-	m_remoteControlFeature( Feature::Session | Feature::Master,
+	m_remoteControlFeature( QStringLiteral( "RemoteControl" ),
+							Feature::Session | Feature::Master,
 							Feature::Uid( "ca00ad68-1709-4abe-85e2-48dff6ccf8a2" ),
 							Feature::Uid(),
-							tr( "Remote control" ), QString(),
+							tr( "Remote control" ), {},
 							tr( "Open a remote control window for a computer." ),
 							QStringLiteral(":/remoteaccess/krdc.png") ),
 	m_features( { m_remoteViewFeature, m_remoteControlFeature } ),
@@ -56,12 +58,6 @@ RemoteAccessFeaturePlugin::RemoteAccessFeaturePlugin( QObject* parent ) :
 
 
 
-RemoteAccessFeaturePlugin::~RemoteAccessFeaturePlugin()
-{
-}
-
-
-
 const FeatureList &RemoteAccessFeaturePlugin::featureList() const
 {
 	return m_features;
@@ -89,14 +85,12 @@ bool RemoteAccessFeaturePlugin::startFeature( VeyonMasterInterface& master, cons
 
 		Computer customComputer;
 		customComputer.setHostAddress( hostName );
+		customComputer.setName( hostName );
 		remoteAccessComputer = ComputerControlInterface::Pointer::create( customComputer );
 	}
-	else
+	else if( computerControlInterfaces.count() >= 1 )
 	{
-		if( computerControlInterfaces.count() >= 1 )
-		{
-			remoteAccessComputer = computerControlInterfaces.first();
-		}
+		remoteAccessComputer = computerControlInterfaces.first();
 	}
 
 	if( remoteAccessComputer.isNull() )
@@ -162,12 +156,12 @@ CommandLinePluginInterface::RunResult RemoteAccessFeaturePlugin::handle_control(
 
 CommandLinePluginInterface::RunResult RemoteAccessFeaturePlugin::handle_help( const QStringList& arguments )
 {
-	if( arguments.value( 0 ) == QStringLiteral("view") )
+	if( arguments.value( 0 ) == QLatin1String("view") )
 	{
 		printf( "\nremoteaccess view <host>\n\n" );
 		return NoResult;
 	}
-	else if( arguments.value( 0 ) == QStringLiteral("control") )
+	else if( arguments.value( 0 ) == QLatin1String("control") )
 	{
 		printf( "\nremoteaccess control <host>\n}n" );
 		return NoResult;
@@ -180,9 +174,9 @@ CommandLinePluginInterface::RunResult RemoteAccessFeaturePlugin::handle_help( co
 
 bool RemoteAccessFeaturePlugin::initAuthentication()
 {
-	if( VeyonCore::instance()->initAuthentication( AuthenticationCredentials::AllTypes ) == false )
+	if( VeyonCore::instance()->initAuthentication() == false )
 	{
-		qWarning() << "Could not initialize authentication";
+		vWarning() << "Could not initialize authentication";
 		return false;
 	}
 
