@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -27,22 +27,12 @@
 #include "AuthenticationCredentials.h"
 #include "ExternalVncServer.h"
 #include "ExternalVncServerConfigurationWidget.h"
+#include "VeyonConfiguration.h"
 
 
 ExternalVncServer::ExternalVncServer( QObject* parent ) :
 	QObject( parent ),
-	m_configuration()
-{
-	// sanitize configuration
-	if( m_configuration.serverPort() <= 0 )
-	{
-		m_configuration.setServerPort( 5900 );
-	}
-}
-
-
-
-ExternalVncServer::~ExternalVncServer()
+	m_configuration( &VeyonCore::config() )
 {
 }
 
@@ -53,10 +43,11 @@ void ExternalVncServer::upgrade( const QVersionNumber& oldVersion )
 	if( oldVersion < QVersionNumber( 1, 1 ) )
 	{
 		// external VNC server password not encrypted yet?
-		if( m_configuration.passwordPlain().size() < MaximumPlaintextPasswordLength )
+		const auto rawPassword = m_configuration.passwordProperty().variantValue().toString();
+		if( rawPassword.size() < MaximumPlaintextPasswordLength )
 		{
 			// setting it again will encrypt it
-			m_configuration.setPassword( m_configuration.passwordPlain() );
+			m_configuration.setPassword( Configuration::Password::fromPlainText( rawPassword ) );
 		}
 	}
 }
@@ -95,5 +86,9 @@ int ExternalVncServer::configuredServerPort()
 
 QString ExternalVncServer::configuredPassword()
 {
-	return m_configuration.password();
+	return m_configuration.password().plainText();
 }
+
+
+
+IMPLEMENT_CONFIG_PROXY(ExternalVncServerConfiguration)
