@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef BUILTIN_ULTRAVNC_SERVER_H
-#define BUILTIN_ULTRAVNC_SERVER_H
+#pragma once
 
 #include "UltraVncConfiguration.h"
 #include "VncServerPluginInterface.h"
@@ -37,7 +36,7 @@ class BuiltinUltraVncServer : public QObject, VncServerPluginInterface, PluginIn
 	Q_INTERFACES(PluginInterface VncServerPluginInterface)
 public:
 	BuiltinUltraVncServer();
-	virtual ~BuiltinUltraVncServer();
+	~BuiltinUltraVncServer() override;
 
 	Plugin::Uid uid() const override
 	{
@@ -87,7 +86,7 @@ public:
 
 	QString configuredPassword() override
 	{
-		return QString();
+		return {};
 	}
 
 	const UltraVncConfiguration& configuration() const
@@ -108,11 +107,11 @@ public:
 private:
 	UltraVncConfiguration m_configuration;
 
+	static constexpr auto DefaultServerPort = 5900;
+
 	int m_serverPort;
 	QString m_password;
 
 	LogoffEventFilter* m_logoffEventFilter;
 
 };
-
-#endif // BUILTIN_ULTRAVNC_SERVER_H
