@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef COMPUTER_CONTROL_CLIENT_H
-#define COMPUTER_CONTROL_CLIENT_H
+#pragma once
 
 #include "VncClientProtocol.h"
 #include "VncProxyConnection.h"
@@ -65,5 +64,3 @@ private:
 	VncClientProtocol m_clientProtocol;
 
 } ;
-
-#endif
