@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2017-2019 Tobias Junghans <tobydox@veyon.io>
  *
- * This file is part of Veyon - http://veyon.io
+ * This file is part of Veyon - https://veyon.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef VNC_PROXY_CONNECTION_FACTORY_H
-#define VNC_PROXY_CONNECTION_FACTORY_H
+#pragma once
 
 class QObject;
 class QTcpSocket;
@@ -40,5 +39,3 @@ public:
 														  QObject* parent ) = 0;
 
 } ;
-
-#endif
